#include "crash.h"

extern struct commandtable command_dis, command_trace, command_pte, command_pgd,
	command_vtop;

const struct commandtable *commandtable_arch[] = {
	&command_dis,
	&command_pgd,
	&command_pte,
	&command_trace,
	&command_vtop,
};
const int ncmdtable_arch = LENGTHOF(commandtable_arch);
